@@ -12,7 +12,7 @@ import netCDF4
 # packing/unpacking of short ints.
 
 # create an n1dim by n2dim random ranarr.
-FILE_NAME = tempfile.mktemp(".nc")
+FILE_NAME = tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name
 ndim = 10
 ranarr = 100.*uniform(size=(ndim))
 ranarr2 = 100.*uniform(size=(ndim))
@@ -28,7 +28,8 @@ ranarr[::2] = missing_value
 ranarr2[::2] = missing_value2
 NP.seterr(invalid='ignore') # silence warnings from ma.masked_values
 maskedarr = ma.masked_values(ranarr,missing_value)
-maskedarr2 = ma.masked_values(ranarr2,missing_value2)
+#maskedarr2 = ma.masked_values(ranarr2,missing_value2)
+maskedarr2 = ma.masked_invalid(ranarr2)
 scale_factor = (packeddata.max()-packeddata.min())/(2.*32766.)
 add_offset = 0.5*(packeddata.max()+packeddata.min())
 packeddata2 = NP.around((packeddata-add_offset)/scale_factor).astype('i2')
@@ -65,6 +66,9 @@ class PrimitiveTypesTestCase(unittest.TestCase):
         doh2 = file.createVariable('packeddata3','i2','n')
         doh2.add_offset = 1.
         doh2[0] = 1.
+        # added test for issue 515
+        file.createDimension('x',1)
+        v = file.createVariable('v',NP.float,'x',fill_value=-9999)
         file.close()
 
     def tearDown(self):
@@ -103,6 +107,8 @@ class PrimitiveTypesTestCase(unittest.TestCase):
         assert(datapacked3[:].dtype == NP.float)
         # added to test fix to issue 46 (result before r865 was 10)
         assert_array_equal(datapacked2[0],11)
+        # added test for issue 515
+        assert(file['v'][0] is NP.ma.masked)
         file.close()
 
 if __name__ == '__main__':
