@@ -8,7 +8,7 @@ import tempfile, unittest, os, datetime
 nx=100; ydim=5; zdim=1
 nfiles = 10
 ninc = nx/nfiles
-files = [tempfile.mktemp(".nc") for nfile in range(nfiles)]
+files = [tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name for nfile in range(nfiles)]
 data = randint(0,10,size=(nx,ydim,zdim))
 missval = 99
 data[::10] = missval
@@ -29,7 +29,7 @@ class VariablesTestCase(unittest.TestCase):
             dat = f.createVariable('data','i',('x','y','z',))
             dat.long_name = 'phony data'
             dat.missing_value = missval
-            nx1 = nfile*ninc; nx2 = ninc*(nfile+1)
+            nx1 = int(nfile*ninc); nx2 = int(ninc*(nfile+1))
             #x[0:ninc] = np.arange(nfile*ninc,ninc*(nfile+1))
             x[:] = np.arange(nfile*ninc,ninc*(nfile+1))
             #dat[0:ninc] = data[nx1:nx2]
@@ -66,7 +66,7 @@ class NonuniformTimeTestCase(unittest.TestCase):
     ninc = 365
     def setUp(self):
 
-        self.files = [tempfile.mktemp(".nc") for nfile in range(2)]
+        self.files = [tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name for nfile in range(2)]
         for nfile,file in enumerate(self.files):
             f = Dataset(file,'w',format='NETCDF4_CLASSIC')
             f.createDimension('time',None)
